Performance Metrics
*******************

Please note that the `SeqMetrics` sub-module has been deprecated. 
Please use `SeqMetrics <https://seqmetrics.readthedocs.io/en/latest/>`_ library instead.

SeqMetrics
=========
.. autoclass:: ai4water.postprocessing.SeqMetrics.Metrics
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

RegressionMetrics
==================
.. autoclass:: ai4water.postprocessing.SeqMetrics.RegressionMetrics
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

ClassificationMetrics
=====================
.. autoclass:: ai4water.postprocessing.SeqMetrics.ClassificationMetrics
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__

Utils
========
.. autoclass:: ai4water.postprocessing.SeqMetrics.utils.plot_metrics
   :members:
   :undoc-members:
   :show-inheritance:

   .. automethod:: __init__
